# Obsolescence Risk Management Capabilities
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-capabilities#overview)
  * [Automated IT Component Discovery and Update](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-capabilities#automated-it-component-discovery-and-update)
  * [Vendor-Provided Lifecycle Information for IT Components](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-capabilities#vendor-provided-lifecycle-information-for-it-components)
  * [Additional Obsolescence Risk Management Views in Reports](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-capabilities#additional-obsolescence-risk-management-views-in-reports)
  * [Dedicated Obsolescence Risk Management Dashboard](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-capabilities#dedicated-obsolescence-risk-management-dashboard)


An overview of features and capabilities of SAP LeanIX Technology Risk and Compliance to proactively identify, assess, and mitigate risks associated with outdated or unsupported technology across your IT landscape.
